Crate alsatimer_sys

Crate alsatimer_sys 

alsatimer-sys crate

Rust FFI bindings and wrappers for alsatimer library to operate ALSA Timer character device.

The alsatimer library version 0.3.0 is the minimum supported version for underlying library.

The alsatimer-sys crate is automatically generated by gir tool provided by gtk-rs project. ALSATimer-0.0 file from alsatimer library is used for the generation.

License

The alsatimer-sys crate is released under MIT license.

Dependency

The alsatimer-sys crate depends on FFI crates provided by gtk-rs project for type/object system, event loop, and dispacher.

Repository

The alsatimer-sys crate is the part of ALSA project and maintained by ALSA gobject-introspection team. The remote repository is located in https://github.com/alsa-project/alsa-gobject-rs.

Support

If finding issue, please file it in https://github.com/alsa-project/alsa-gobject-rs.

Structs

ALSATimerDeviceId
ALSATimerDeviceInfo
ALSATimerDeviceInfoClass
ALSATimerDeviceParams
ALSATimerDeviceParamsClass
ALSATimerDeviceStatus
ALSATimerDeviceStatusClass
ALSATimerInstanceInfo
ALSATimerInstanceInfoClass
ALSATimerInstanceParams
ALSATimerInstanceParamsClass
ALSATimerInstanceStatus
ALSATimerInstanceStatusClass
ALSATimerRealTimeEvent
ALSATimerTickTimeEvent
ALSATimerUserInstance
ALSATimerUserInstanceClass

Constants

ALSATIMER_CLASS_CARD
ALSATIMER_CLASS_GLOBAL
ALSATIMER_CLASS_NONE
ALSATIMER_CLASS_PCM
ALSATIMER_DEVICE_INFO_FLAG_SLAVE
ALSATIMER_EVENT_TYPE_REAL_TIME
ALSATIMER_EVENT_TYPE_TICK_TIME
ALSATIMER_INSTANCE_PARAM_FLAG_AUTO
ALSATIMER_INSTANCE_PARAM_FLAG_EARLY_EVENT
ALSATIMER_INSTANCE_PARAM_FLAG_EXCLUSIVE
ALSATIMER_REAL_TIME_EVENT_TYPE_CONTINUE
ALSATIMER_REAL_TIME_EVENT_TYPE_EARLY
ALSATIMER_REAL_TIME_EVENT_TYPE_MCONTINUE
ALSATIMER_REAL_TIME_EVENT_TYPE_MPAUSE
ALSATIMER_REAL_TIME_EVENT_TYPE_MRESUME
ALSATIMER_REAL_TIME_EVENT_TYPE_MSTART
ALSATIMER_REAL_TIME_EVENT_TYPE_MSTOP
ALSATIMER_REAL_TIME_EVENT_TYPE_MSUSPEND
ALSATIMER_REAL_TIME_EVENT_TYPE_PAUSE
ALSATIMER_REAL_TIME_EVENT_TYPE_RESOLUTION
ALSATIMER_REAL_TIME_EVENT_TYPE_RESUME
ALSATIMER_REAL_TIME_EVENT_TYPE_START
ALSATIMER_REAL_TIME_EVENT_TYPE_STOP
ALSATIMER_REAL_TIME_EVENT_TYPE_SUSPEND
ALSATIMER_REAL_TIME_EVENT_TYPE_TICK
ALSATIMER_SLAVE_CLASS_APPLICATION
ALSATIMER_SLAVE_CLASS_NONE
ALSATIMER_SLAVE_CLASS_SEQUENCER
ALSATIMER_SPECIFIC_GLOBAL_DEVICE_HRTIMER
ALSATIMER_SPECIFIC_GLOBAL_DEVICE_SYSTEM
ALSATIMER_USER_INSTANCE_ERROR_ATTACHED
ALSATIMER_USER_INSTANCE_ERROR_FAILED
ALSATIMER_USER_INSTANCE_ERROR_NOT_ATTACHED
ALSATIMER_USER_INSTANCE_ERROR_TIMER_NOT_FOUND

Functions

alsatimer_class_get_type⚠
alsatimer_device_id_get_card_id⚠
alsatimer_device_id_get_class⚠
alsatimer_device_id_get_device_id⚠
alsatimer_device_id_get_subdevice_id⚠
alsatimer_device_id_get_type⚠
alsatimer_device_id_new⚠
alsatimer_device_info_flag_get_type⚠
alsatimer_device_info_get_type⚠
alsatimer_device_params_get_type⚠
alsatimer_device_params_new⚠
alsatimer_device_status_get_type⚠
alsatimer_device_status_new⚠
alsatimer_event_type_get_type⚠
alsatimer_get_device_id_list⚠
alsatimer_get_device_info⚠
alsatimer_get_device_status⚠
alsatimer_get_devnode⚠
alsatimer_get_real_time_clock_id⚠
alsatimer_get_sysname⚠
alsatimer_instance_info_get_type⚠
alsatimer_instance_param_flag_get_type⚠
alsatimer_instance_params_get_event_filter⚠
alsatimer_instance_params_get_type⚠
alsatimer_instance_params_new⚠
alsatimer_instance_params_set_event_filter⚠
alsatimer_instance_status_get_time⚠
alsatimer_instance_status_get_type⚠
alsatimer_instance_status_new⚠
alsatimer_real_time_event_get_event⚠
alsatimer_real_time_event_get_time⚠
alsatimer_real_time_event_get_type⚠
alsatimer_real_time_event_get_val⚠
alsatimer_real_time_event_type_get_type⚠
alsatimer_set_device_params⚠
alsatimer_slave_class_get_type⚠
alsatimer_specific_global_device_get_type⚠
alsatimer_tick_time_event_get_count⚠
alsatimer_tick_time_event_get_resolution⚠
alsatimer_tick_time_event_get_type⚠
alsatimer_user_instance_attach⚠
alsatimer_user_instance_attach_as_slave⚠
alsatimer_user_instance_choose_event_type⚠
alsatimer_user_instance_continue⚠
alsatimer_user_instance_create_source⚠
alsatimer_user_instance_error_get_type⚠
alsatimer_user_instance_error_quark⚠
alsatimer_user_instance_get_info⚠
alsatimer_user_instance_get_protocol_version⚠
alsatimer_user_instance_get_status⚠
alsatimer_user_instance_get_type⚠
alsatimer_user_instance_new⚠
alsatimer_user_instance_open⚠
alsatimer_user_instance_pause⚠
alsatimer_user_instance_set_params⚠
alsatimer_user_instance_start⚠
alsatimer_user_instance_stop⚠

Type Aliases

ALSATimerClass
ALSATimerDeviceInfoFlag
ALSATimerEventType
ALSATimerInstanceParamFlag
ALSATimerRealTimeEventType
ALSATimerSlaveClass
ALSATimerSpecificGlobalDevice
ALSATimerUserInstanceError